<?php

namespace Litepie\Blog\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litepie\Blog\Actions\BlogAction;
use Litepie\Blog\Http\Requests\BlogActionRequest;
use Litepie\Blog\Http\Resources\BlogResource;
use Litepie\Blog\Models\Blog;

/**
 * Admin web controller class.
 */
class BlogActionController extends BaseController
{

    /**
     * Action controller function for blog.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlogActionRequest $request, Blog $blog, $action)
    {
        try {
            $request = $request->all();
            $blog = BlogAction::run($action, $blog, $request);

            $data = new BlogResource($blog);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('blog::blog.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blog/blog/' . $blog->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog/' . $blog->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
