<?php

namespace Litepie\Blog\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litepie\Blog\Actions\BlogCategoryAction;
use Litepie\Blog\Http\Requests\BlogCategoryActionRequest;
use Litepie\Blog\Http\Resources\BlogCategoryResource;
use Litepie\Blog\Models\BlogCategory;

/**
 * Admin web controller class.
 */
class BlogCategoryActionController extends BaseController
{

    /**
     * Action controller function for blog_category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlogCategoryActionRequest $request, BlogCategory $blog_category, $action)
    {
        try {
            $request = $request->all();
            $blog_category = BlogCategoryAction::run($action, $blog_category, $request);

            $data = new BlogCategoryResource($blog_category);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' . $blog_category->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
