<?php

namespace Litepie\Blog\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litepie\Blog\Http\Requests\BlogCategoryActionsRequest;
use Litepie\Blog\Actions\BlogCategoryActions;

/**
 * Admin web controller class.
 */
class BlogCategoryActionsController extends BaseController
{

    /**
     * Action controller function for blog_category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlogCategoryActionsRequest $request, $action)
    {
        try {
            $blog_category = BlogCategoryActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('blog::blog_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blog/blog_category/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog_category/' . $action))
                ->redirect();
        }
    }
}
