<?php

namespace Litepie\Blog\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litepie\Blog\Actions\BlogExim;
use Litepie\Blog\Http\Requests\BlogEximRequest;

/**
 * Admin web controller class.
 */
class BlogEximController extends BaseController
{
    /**
     * Action controller function for blog.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BlogEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = BlogExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('blog:blog.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('blog/blog/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('blog/blog/' . $exim))
                ->redirect();
        }
    }
}
