<?php

namespace Litepie\Blog\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litepie\Blog\Events\BlogCategoryAction as BlogCategoryActionEvent;
use Litepie\Blog\Notifications\BlogCategoryAction as BlogCategoryActionNotification;
use Litepie\Actions\Concerns\AsAction;

class BlogCategoryAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the BlogCategoryActionEvent.
     *
     * @param   BlogCategoryActionEvent  $event
     * @return mixed
     */
    public function handle(BlogCategoryActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $blog_category.
     *
     * @param   BlogCategoryActionEvent  $event
     * @return void
     */
    public function create(BlogCategoryActionEvent $event)
    {
        $client = $event->blog_category->client;
        Notification::send($client, new BlogCategoryActionNotification($event));
    }

    /**
     * Handle the BlogCategoryActionEvent as a listener.
     *
     * @param   BlogCategoryActionEvent  $event
     * @return mixed
     */
    public function asListener(BlogCategoryActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   BlogCategoryActionEvent  $event
     * @return bool
     */
    private function isAllowed(BlogCategoryActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
