<?php
namespace Litepie\Blog\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litepie\Blog\Events\BlogCategoryAction as BlogCategoryActionEvent;
use Litepie\Blog\Models\BlogCategory;

class BlogCategoryAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $blog_category;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BlogCategoryActionEvent $blog_category
     */
    public function __construct(BlogCategoryActionEvent $blog_category)
    {
        $this->action = $event->action;
        $this->blog_category = $blog_category;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('BlogCategory Approved - ' . config('app.name'))
            ->view('blog::blog_category.email.action', ['data' => $this->blog_category]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
