<?php

namespace Litepie\Blog\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litepie\Blog\Models\BlogCategory;

class BlogCategoryPolicy
{

    use BlogCategoryAction;
    use BlogCategoryExim;

    /**
     * Determine if the given user can view the blog_category.
     *
     * @param Authenticatable $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function view(Authenticatable $user, BlogCategory $blog_category)
    {
        if ($authUser->canDo('blog.blog_category.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $blog_category->is_owner;
    }

    /**
     * Determine if the given user can create a blog_category.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('blog.blog_category.create');
    }

    /**
     * Determine if the given user can update the given blog_category.
     *
     * @param Authenticatable $user
     * @param BlogCategory $blog_category
     *
     * @return bool
     */
    public function update(Authenticatable $user, BlogCategory $blog_category)
    {
        if ($user->canDo('blog.blog_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $blog_category->is_owner;
    }

    /**
     * Determine if the given user can delete the given blog_category.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, BlogCategory $blog_category)
    {
        return $blog_category->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
